==> mgb-0.6.2.tar.gz: load_settings.inc.php <==
<?php
	
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2007 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

        You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

        // =========================== //
	// load_settings.inc.php - 1.0 //
	// =========================== //
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //
	
	// load settings from database
        $sql = "SELECT
			title,
			h_author,
			h_domain,
			gb_path,
			h_keywords,
			h_description,
			admin_name,
			admin_email,
			admin_gbemail,
			sendmail_admin,
			sendmail_admin_text,
			sendmail_user,
			sendmail_user_text,
			sendmail_user_notification_text,
			sendmail_comment_text,
			sendmail_contactmail_text,
			template_path,
			template_style_path,
			iconset_path,
			language_path,
			badwords,
			bbcode,
			smileys,
			captcha,
			user_notification,
			user_show_email,
			session_timeout,
			moderated,
			entries_per_page,
			entries_order,
			spam_protection,
			ipblocker,
			wordwrap,
			dateform,
			gravatar_show,
			gravatar_rating,
			version FROM ".$db['prefix']."settings";
			
        $link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(load_settings.php) Error: ".mysql_error());
        @mysql_select_db($db['dbname'], $link) or die ("(load_settings.php) Error: ".mysql_error());
        $result = @mysql_query($sql, $link) or die ("(load_settings.php) Error: ".mysql_error()."<br><br>Maybe you've forgotten to <a href=\"install/upgrade.php\" title=\"upgrade\">upgrade</a> your installation.");

	$settings = @mysql_fetch_array($result);
	
	$settings['sendmail_admin_text'] = xhtmlbr2nl($settings['sendmail_admin_text']);
	$settings['sendmail_user_text'] = xhtmlbr2nl($settings['sendmail_user_text']);
	$settings['sendmail_user_notification_text'] = xhtmlbr2nl($settings['sendmail_user_notification_text']);
	$settings['sendmail_comment_text'] = xhtmlbr2nl($settings['sendmail_comment_text']);
	$settings['sendmail_contactmail_text'] = xhtmlbr2nl($settings['sendmail_contactmail_text']);
?>

==> mgb-0.6.3.tar.gz: load_settings.inc.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2007 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// =========================== //
	// load_settings.inc.php - 1.0 //
	// =========================== //
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

	// load settings from database
	$sql = "SELECT
			title,
			h_author,
			h_domain,
			gb_path,
			h_keywords,
			h_description,
			admin_name,
			admin_email,
			admin_gbemail,
			sendmail_admin,
			sendmail_admin_text,
			sendmail_user,
			sendmail_user_text,
			sendmail_user_notification_text,
			sendmail_comment_text,
			sendmail_contactmail_text,
			template_path,
			template_style_path,
			iconset_path,
			language_path,
			badwords,
			bbcode,
			smileys,
			captcha,
			user_notification,
			user_show_email,
			session_timeout,
			moderated,
			entries_per_page,
			entries_order,
			spam_protection,
			ipblocker,
			wordwrap,
			dateform,
			gravatar_show,
			gravatar_rating,
			version FROM ".$db['prefix']."settings";

	$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(load_settings.inc.php) Error, line 67: ".mysql_error());
	@mysql_select_db($db['dbname'], $link) or die ("(load_settings.inc.php) Error, line 68: ".mysql_error());
	$result = @mysql_query($sql, $link) or die ("(load_settings.inc.php) Error, line 69: ".mysql_error()."<br><br>Maybe you've forgotten to <a href=\"install/upgrade.php\" title=\"upgrade\">upgrade</a> your installation?");

	$settings = @mysql_fetch_array($result);

	$settings['sendmail_admin_text'] = xhtmlbr2nl($settings['sendmail_admin_text']);
	$settings['sendmail_user_text'] = xhtmlbr2nl($settings['sendmail_user_text']);
	$settings['sendmail_user_notification_text'] = xhtmlbr2nl($settings['sendmail_user_notification_text']);
	$settings['sendmail_comment_text'] = xhtmlbr2nl($settings['sendmail_comment_text']);
	$settings['sendmail_contactmail_text'] = xhtmlbr2nl($settings['sendmail_contactmail_text']);
?>
